@@ -1,13 +1,11 @@
 package Set::Scalar;
 
 use strict;
-local $^W = 1;
+# local $^W = 1;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = '1.20';
-
-use Scalar::Util qw(blessed refaddr);
+$VERSION = '1.22';
 
 @ISA = qw(Set::Scalar::Real Set::Scalar::Null Set::Scalar::Base);
 
@@ -62,15 +60,16 @@ Set::Scalar - basic set operations
     $s = Set::Scalar->new(@members); 
 
     $t = $s->clone;
-    $t = $s->copy; # clone of clone
+    $t = $s->copy;         # Clone of clone.
+    $t = $s->empty_clone;  # Like clone() but with no members.
 
 =head2 Modifying
 
     $s->insert(@members);
     $s->delete(@members);
-    $s->invert(@members); # insert if hasn't, delete if has
+    $s->invert(@members);  # Insert if hasn't, delete if has.
 
-    $s->clear; # removes all the elements
+    $s->clear;  # Removes all the elements.
 
 Note that clear() only releases the memory used by the set to
 be reused by Perl; it will not reduce the overall memory use.
@@ -89,25 +88,25 @@ See L</"Customising Display"> for customising the set display.
 =head2 Querying
 
     @members  = $s->members;
-    @elements = $s->elements; # alias for members
+    @elements = $s->elements;  # Alias for members.
 
-    $size = $s->size; # the number of members
+    $size = $s->size;  # The number of members.
 
-    $s->has($m)       # return true if has that member
-    $s->contains($m)  # alias for has
+    $s->has($m)        # Return true if has that member.
+    $s->contains($m)   # Alias for has().
 
     if ($s->has($member)) { ... }
 
-    $s->member($m)    # returns the member if has that member
-    $s->element($m)   # alias for member
+    $s->member($m)     # Returns the member if has that member.
+    $s->element($m)    # Alias for member.
 
-    $s->is_null       # returns true if the set is empty
-    $s->is_empty      # alias for is_null
-    $s->is_universal  # returns true if the set is universal
+    $s->is_null        # Returns true if the set is empty.
+    $s->is_empty       # Alias for is_null.
+    $s->is_universal   # Returns true if the set is universal.
 
-    $s->null          # the null set
-    $s->empty         # alias for null
-    $s->universe      # the universe of the set
+    $s->null           # The null set.
+    $s->empty          # Alias for null.
+    $s->universe       # The universe of the set.
 
 =head2 Deriving
 
@@ -120,12 +119,12 @@ See L</"Customising Display"> for customising the set display.
 
 These methods have operator overloads:    
 
-    $u = $s + $t; # union
-    $i = $s * $t; # intersection
-    $d = $s - $t; # difference
-    $e = $s % $t; # symmetric_difference
-    $v = $s / $t; # unique
-    $c = -$s;     # complement
+    $u = $s + $t;  # union
+    $i = $s * $t;  # intersection
+    $d = $s - $t;  # difference
+    $e = $s % $t;  # symmetric_difference
+    $v = $s / $t;  # unique
+    $c = -$s;      # complement
 
 Both the C<symmetric_difference> and C<unique> are symmetric on all
 their arguments.  For two sets they are identical but for more than
@@ -172,13 +171,13 @@ intersect", and in future (once I get around implementing it),
 
 These methods have operator overloads:    
 
-    $eq = $s == $t; # is_equal
-    $dj = $s != $t; # is_disjoint
+    $eq = $s == $t;  # is_equal
+    $dj = $s != $t;  # is_disjoint
     # No operator overload for is_properly_intersecting.
-    $ps = $s < $t;  # is_proper_subset
-    $pS = $s > $t;  # is_proper_superset
-    $is = $s <= $t; # is_subset
-    $iS = $s >= $t; # is_superset
+    $ps = $s < $t;   # is_proper_subset
+    $pS = $s > $t;   # is_proper_superset
+    $is = $s <= $t;  # is_subset
+    $iS = $s >= $t;  # is_superset
 
     $cmp = $s <=> $t;
 
@@ -218,11 +217,11 @@ So don't expect any particular order.
 When no more elements remain C<undef> is returned.  Since you may one
 day have elements named C<0> don't test just like this
 
-    while (my $e = $s->each) { ... }          # WRONG
+    while (my $e = $s->each) { ... }           # WRONG!
 
 but instead like this
 
-    while (defined(my $e = $s->each)) { ... } # right
+    while (defined(my $e = $s->each)) { ... }  # Right.
 
 (An C<undef> as a set element doesn't really work, you get C<"">.)
 
@@ -244,6 +243,86 @@ that, either.
 
 =back
 
+=head2 Cartesian Product and Power Set
+
+=over 4
+
+=item *
+
+Cartesian product is a product of two or more sets.  For two sets, it
+is the set consisting of B<ordered pairs> of members from each set.
+For example for the sets
+
+  (a b)
+  (c d e)
+
+The Cartesian product of the above is the set
+
+  ([a, c] [a, d] [a, e] [b, c] [b, d] [b, e])
+
+The [,] notation is for the ordered pairs, which sets are are not.
+This means two things: firstly, that [e, b] is B<not> in the above
+Cartesian product, and secondly, [b, b] is a possibility:
+
+  (a b)
+  (b c e)
+
+  ([a, b] [a, c] [a, e] [b, b] [b, c] [b, d])
+
+For example:
+
+  my $a = Set::Scalar->new(1..2);
+  my $b = Set::Scalar->new(3..5);
+  my $c = $a->cartesian_product($b);  # As an object method. 
+  my $d = Set::Scalar->cartesian_product($a, $b);  # As a class method.
+
+The $c and $d will be of the same class as $a.  The members of $c and
+$c in the above will be anonymous arrays (array references), not sets,
+since sets wouldn't be able to represent the ordering or that a member
+can be present more than once.  Also note that since the members of
+the input sets are unordered, the ordered pairs themselves are
+unlikely to be in any particular order.
+
+If you don't want to construct the Cartesian product set, you can
+construct an iterator and call it while it returns more members:
+
+   my $iter = Set::Scalar->cartesian_product_iterator($a, $b, $c);
+   while (my @m = $iter->()) {
+     process(@m);
+   }
+
+=item *
+
+Power set is the set of all the subsets of a set.  If the set has N
+members, its power set has 2**N members.  For example for the set
+
+    (a b c)
+
+size 3, its power set is
+
+    (() (a) (b) (c) (a b) (a c) (b c) (a b c))
+
+size 8.  Note that since the elements of the power set are sets, they
+are unordered, and therefore (b c) is equal to (c b).  For example:
+
+    my $a = Set::Scalar->new(1..3);
+    my $b = $a->power_set;               # As an object method.
+    my $c = Set::Scalar->power_set($a);  # As a class method.
+
+Even the empty set has a power set, of size one.
+
+If you don't want to construct the power set, you can construct an
+iterator and call it until it returns no more members:
+
+   my $iter = Set::Scalar->power_set($a);
+   my @m;
+   do {
+     @m = $iter->();
+     process(@m);
+   } while (@m);
+
+=back
+
 =head2 Customising Display
 
 If you want to customise the display routine you will have to
